@@ -24,6 +24,7 @@ describe 'designate::logging' do
      :instance_uuid_format => '[instance: %(uuid)s] ',
      :log_date_format => '%Y-%m-%d %H:%M:%S',
      :use_syslog => true,
+     :use_json => true,
      :use_stderr => false,
      :log_facility => 'LOG_FOO',
      :log_dir => '/var/log',
@@ -56,11 +57,12 @@ describe 'designate::logging' do
   shared_examples 'basic default logging settings' do
     it 'configures designate logging settings with default values' do
       is_expected.to contain_oslo__log('designate_config').with(
-        :use_syslog   => '<SERVICE DEFAULT>',
-        :use_stderr   => '<SERVICE DEFAULT>',
+        :use_syslog          => '<SERVICE DEFAULT>',
+        :use_json            => '<SERVICE DEFAULT>',
+        :use_stderr          => '<SERVICE DEFAULT>',
         :syslog_log_facility => '<SERVICE DEFAULT>',
-        :log_dir      => '/var/log/designate',
-        :debug        => '<SERVICE DEFAULT>',
+        :log_dir             => '/var/log/designate',
+        :debug               => '<SERVICE DEFAULT>',
       )
     end
   end
@@ -68,11 +70,12 @@ describe 'designate::logging' do
   shared_examples 'basic non-default logging settings' do
     it 'configures designate logging settings with non-default values' do
       is_expected.to contain_oslo__log('designate_config').with(
-        :use_syslog   => true,
-        :use_stderr   => false,
+        :use_syslog          => true,
+        :use_json            => true,
+        :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
-        :log_dir      => '/var/log',
-        :debug        => true,
+        :log_dir             => '/var/log',
+        :debug               => true,
       )
     end
   end
